using UnityEngine;
using System.Collections;

public class EnemyController : MonoBehaviour
{
		public GameObject player;
		public float step = 0.2f;
		public float speed = 100.0f;
		public float shootingInterval = 1f;
		public int projectilesPerSalvo = 10;
		public float projectileRate = 0.05f;
		Vector3 target = new Vector3 (0, -1.3f, 0);
		float minDistanceToTarget = 3f;
		Gun gun;
		GunAiming gunAiming;
		Transform spriteTransform;
		public bool isInfluencedByFlower;

		// Use this for initialization
		void Start ()
		{
				spriteTransform = gameObject.transform.GetChild (0);
				gun = gameObject.GetComponentInChildren<Gun> ();
				gunAiming = gameObject.GetComponentInChildren<GunAiming> ();
				GameObject sceneManager = GameObject.Find ("SceneManager");
				InvokeRepeating ("FireSalvo", 0, shootingInterval);
				player = CombatSceneManager.getPlayer ();
		}
	
		// Update is called once per frame
		void Update ()
		{
				if (FlowerCollection.GetInstance ().IsInfluencedByFlower (gameObject)) {
						gameObject.transform.eulerAngles = new Vector3 (0, 0, 90);
						isInfluencedByFlower = true;
						CancelInvoke("FireSalvo");
						CombatSceneManager.getInstance().AddEnemyControllerInfluenced(this);
						this.enabled = false;
						return;
				}
				transform.eulerAngles = new Vector3 (0, 0, 0);

				if (Vector3.Distance (transform.position, player.transform.position) > minDistanceToTarget) {
						transform.position = Vector3.MoveTowards (transform.position, player.transform.position, speed * Time.deltaTime);
				}

				if ((player.transform.position.x > transform.position.x && spriteTransform.localScale.x < 0)
						|| (player.transform.position.x < transform.position.x && spriteTransform.localScale.x > 0))
						spriteTransform.localScale = new Vector3 (-spriteTransform.localScale.x, 
			                                         spriteTransform.localScale.y, spriteTransform.localScale.z);

		}

		void FireSalvo ()
		{
				if (!isInfluencedByFlower) {
						if (Vector3.Distance (transform.position, player.transform.position) > 10)
								return;
						if (gun != null && gunAiming != null) {
								if (gameObject.transform.position.x < player.transform.position.x) {
										gunAiming.AimRight ();
								} else {
										gunAiming.AimLeft ();
								}	
								for (int i=0; i<projectilesPerSalvo; i++) {
										Invoke ("FireProjectile", projectileRate * i);
								}
						}
				}
		}

		void FireProjectile ()
		{
				gun.FireSalvo (1);
				//GameObject projectileClone = (GameObject)Instantiate (projectile, transform.position, transform.rotation);
		}

		void OnTriggerEnter (Collider other)
		{
		
				if (other.gameObject.tag == "Projectile") {
						CombatSceneManager.getInstance ().RemoveEnemyController (this);
						SoundManager.playSoundHurt ();
						Destroy (other.gameObject);
						Destroy (gameObject);
				}
		
		}
}

